You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by zw...@apache.org on 2010/11/16 21:22:08 UTC

svn commit: r1035782 [14/29] - in /trafficserver/traffic/trunk: example/add-header/ example/append-transform/ example/basic-auth/ example/blacklist-0/ example/blacklist-1/ example/bnull-transform/ example/cache_plugin/ example/cache_scan/ example/file-...

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SimBasicAuth-1.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SimBasicAuth-1.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SimBasicAuth-1.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SimBasicAuth-1.c Tue Nov 16 20:22:02 2010
@@ -92,27 +92,27 @@ typedef struct
 SimSDKtestPlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
   /* register the plugin functions that are called back
    * later in the program */
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 
 }
 
 /* process options specified in SDKtest_client.config */
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -146,7 +146,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -154,15 +154,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
 
@@ -184,7 +184,7 @@ INKPluginFinish()
  *     i.e. GET URL HTTP/1.0 ....
  */
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -197,7 +197,7 @@ INKRequestCreate(char *origin_server_hos
   /*char *url_line = (char *)malloc(MAX_URL_LEN + 1); */
   char url_line[MAX_URL_LEN];
 
-  /*printf ("DEBUG: INKRequestCreate: -------- START\n"); */
+  /*printf ("DEBUG: TSRequestCreate: -------- START\n"); */
   getUrl(my_plugin.url_file, url_line);
 
   /* SDKtest in "Direct" mode */
@@ -222,25 +222,25 @@ INKRequestCreate(char *origin_server_hos
   *req_id = (void *) user;
   my_plugin.requests++;
 
-  /*printf ("DEBUG: INKRequestCreate: -------- END\n"); */
+  /*printf ("DEBUG: TSRequestCreate: -------- END\n"); */
   return TRUE;
 }
 
 /* process response header returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 /* process part of the response returned either from synthetic
  * server or from proxy server
  */
 /*
-INKRequestAction INKPartialBodyProcess(void *req_id,
+TSRequestAction TSPartialBodyProcess(void *req_id,
 		void *partial_content,
 		int partial_length,
 		int accum_length)
@@ -254,25 +254,25 @@ INKRequestAction INKPartialBodyProcess(v
 			fprintf(stderr, "ERROR: received bytes < requested bytes");
 		}
 	}
-	return INK_KEEP_GOING;
+	return TS_KEEP_GOING;
 }
 */
 
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 /* output report data after the SDKtest report */
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
 }
 
 /******************** ADDED FUNCTIONS ****************************/

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBench.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBench.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBench.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBench.c Tue Nov 16 20:22:02 2010
@@ -81,23 +81,23 @@ typedef struct
 SimInkbenchPlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -123,7 +123,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -131,15 +131,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
   free(my_plugin.target_host);
@@ -152,7 +152,7 @@ INKPluginFinish()
 
 
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -184,16 +184,16 @@ INKRequestCreate(char *origin_server_hos
 }
 
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
   if (partial_length == 0) {
     if (accum_length >= ((User *) req_id)->doc_size_requested) {
@@ -203,19 +203,19 @@ INKPartialBodyProcess(void *req_id, void
       fprintf(stderr, "ERROR: received bytes < requested bytes");
     }
   }
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 #define safediv(top,bottom) ((bottom) ? (((double)(top))/((double)(bottom))) : (bottom))
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
-  INKReportSingleData("Average Bytes Per Request", "bytes/req", INK_AVE,
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Average Bytes Per Request", "bytes/req", TS_AVE,
                       (double) safediv(my_plugin.total_bytes_received, my_plugin.successful_requests));
 }
 

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBenchCache.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBenchCache.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBenchCache.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SimInkBenchCache.c Tue Nov 16 20:22:02 2010
@@ -90,23 +90,23 @@ typedef struct
 InkBenchCachePlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -134,7 +134,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -142,15 +142,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
   free(my_plugin.target_host);
@@ -163,7 +163,7 @@ INKPluginFinish()
 
 
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -211,16 +211,16 @@ INKRequestCreate(char *origin_server_hos
 }
 
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
   if (partial_length == 0) {
     if (accum_length >= ((User *) req_id)->doc_size_requested) {
@@ -230,19 +230,19 @@ INKPartialBodyProcess(void *req_id, void
       fprintf(stderr, "ERROR: received bytes < requested bytes");
     }
   }
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 #define safediv(top,bottom) ((bottom) ? (((double)(top))/((double)(bottom))) : (bottom))
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
-  INKReportSingleData("Average Bytes Per Request", "bytes/req", INK_AVE,
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Average Bytes Per Request", "bytes/req", TS_AVE,
                       (double) safediv(my_plugin.total_bytes_received, my_plugin.successful_requests));
 }
 

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtest.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtest.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtest.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtest.c Tue Nov 16 20:22:02 2010
@@ -83,26 +83,26 @@ typedef struct
 SimSDKtestPlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
   /* register the plugin functions that are called back
    * later in the program */
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 /* process options specified in SDKtest_client.config */
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -128,7 +128,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -136,15 +136,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
   free(my_plugin.target_host);
@@ -163,7 +163,7 @@ INKPluginFinish()
  *     i.e. GET URL HTTP/1.0 ....
  */
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -197,18 +197,18 @@ INKRequestCreate(char *origin_server_hos
 /* process response header returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 /* process part of the response returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
   if (partial_length == 0) {
     if (accum_length >= ((User *) req_id)->doc_size_requested) {
@@ -218,18 +218,18 @@ INKPartialBodyProcess(void *req_id, void
       fprintf(stderr, "ERROR: received bytes < requested bytes");
     }
   }
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 /* output report data after the SDKtest report */
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
 }
 
 /******************** ADDED FUNCTIONS ****************************/

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtestCache.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtestCache.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtestCache.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SimSDKtestCache.c Tue Nov 16 20:22:02 2010
@@ -93,26 +93,26 @@ typedef struct
 SDKtestCachePlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
   /* register the plugin functions that are called back
    * later in the program */
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 /* process options specified in SDKtest_client.config */
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -140,7 +140,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -148,15 +148,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
   free(my_plugin.target_host);
@@ -175,7 +175,7 @@ INKPluginFinish()
  *     i.e. GET URL HTTP/1.0 ....
  */
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -225,18 +225,18 @@ INKRequestCreate(char *origin_server_hos
 /* process response header returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 /* process part of the response returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
   if (partial_length == 0) {
     if (accum_length >= ((User *) req_id)->doc_size_requested) {
@@ -246,18 +246,18 @@ INKPartialBodyProcess(void *req_id, void
       fprintf(stderr, "ERROR: received bytes < requested bytes");
     }
   }
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 /* output report data after the SDKtest report */
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
 }
 
 /******************** ADDED FUNCTIONS ****************************/

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/SingleHostFilter.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/SingleHostFilter.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/SingleHostFilter.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/SingleHostFilter.c Tue Nov 16 20:22:02 2010
@@ -71,7 +71,7 @@ URL_TYPE select_url_catagory();
 FilterPlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.allowed_requests = 0;
@@ -79,7 +79,7 @@ INKPluginInit(int client_id)
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -93,7 +93,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   if ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) {
     my_plugin.direct = 1;
@@ -104,7 +104,7 @@ INKOptionsProcessFinish()
 
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   /* do clean up here */
   free(my_plugin.target_host);
@@ -114,7 +114,7 @@ INKPluginFinish()
 
 
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -151,32 +151,32 @@ INKRequestCreate(char *origin_server_hos
 }
 
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   if (strstr(header, "200 OK")) {
-    return INK_KEEP_GOING;
+    return TS_KEEP_GOING;
   }
   /* since SDKtest_client core will treat non 200 response as fail request,
    * we need to specify it as a successful request explicitly
    */
   else if (strstr(header, "403 Forbidden")) {
-    return INK_STOP_SUCCESS;
+    return TS_STOP_SUCCESS;
   } else if (strstr(header, "302 Moved Temporarily")) {
-    return INK_STOP_SUCCESS;
+    return TS_STOP_SUCCESS;
   } else {
-    return INK_STOP_FAIL;
+    return TS_STOP_FAIL;
   }
 }
 
 
 #define safediv(top,bottom) ((bottom) ? (((double)(top))/((double)(bottom))) : (bottom))
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData((char *) "Allowed Requests", (char *) "count", INK_SUM, (double) my_plugin.allowed_requests);
-  INKReportSingleData((char *) "Forbidden Requests", (char *) "count", INK_SUM, (double) my_plugin.forbidden_requests);
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData((char *) "Allowed Requests", (char *) "count", TS_SUM, (double) my_plugin.allowed_requests);
+  TSReportSingleData((char *) "Forbidden Requests", (char *) "count", TS_SUM, (double) my_plugin.forbidden_requests);
 }
 
 

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/connection_finish.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/connection_finish.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/connection_finish.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/connection_finish.c Tue Nov 16 20:22:02 2010
@@ -25,29 +25,29 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
   fprintf(stderr, "connection finish!!!\n");
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
 }
 
 void
-INKConnectionFinish(void *rid, INKConnectionStatus status)
+TSConnectionFinish(void *rid, TSConnectionStatus status)
 {
   switch (status) {
-  case INK_CONN_COMPLETE:
+  case TS_CONN_COMPLETE:
     fprintf(stderr, "c");
     break;
-  case INK_TIME_EXPIRE:
+  case TS_TIME_EXPIRE:
     fprintf(stderr, "x");
     break;
-  case INK_CONN_ERR:
+  case TS_CONN_ERR:
     fprintf(stderr, "e");
     break;
-  case INK_READ_ERR:
+  case TS_READ_ERR:
     fprintf(stderr, "r");
     break;
-  case INK_WRITE_ERR:
+  case TS_WRITE_ERR:
     fprintf(stderr, "w");
     break;
   default:

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/header_process.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/header_process.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/header_process.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/header_process.c Tue Nov 16 20:22:02 2010
@@ -29,15 +29,15 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKHeaderProcess Test for Client ***\n");
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
+  fprintf(stderr, "*** TSHeaderProcess Test for Client ***\n");
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
 }
 
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/hello_world.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/hello_world.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckAppend.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckAppend.c Tue Nov 16 20:22:02 2010
@@ -78,19 +78,19 @@ typedef struct
 CheckAppendPlugin my_plugin;
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
   fprintf(stderr, "*** CheckAppend Test for append-transform-plugin v0.0***\n");
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
 }
 
 void
-INKConnectionFinish(void *request_id, INKConnectionStatus status)
+TSConnectionFinish(void *request_id, TSConnectionStatus status)
 {
 
   /*print_debug((stderr, "Freeing %x\n", request_id)); */
@@ -99,31 +99,31 @@ INKConnectionFinish(void *request_id, IN
 
   /*fprintf(stderr, "CONN %x FINISH with status", request_id);
      switch(status) {
-     case INK_CONN_COMPLETE:
-     fprintf(stderr, "INK_CONN_COMPLETE\n");
+     case TS_CONN_COMPLETE:
+     fprintf(stderr, "TS_CONN_COMPLETE\n");
      break;
 
-     case INK_CONN_ERR:
-     fprintf(stderr, "INK_CONN_ERR\n");
+     case TS_CONN_ERR:
+     fprintf(stderr, "TS_CONN_ERR\n");
      break;
 
-     case INK_READ_ERR:
-     fprintf(stderr, "INK_READ_ERR\n");
+     case TS_READ_ERR:
+     fprintf(stderr, "TS_READ_ERR\n");
      break;
 
-     case INK_WRITE_ERR:
-     fprintf(stderr, "INK_WRITE_ERR\n");
+     case TS_WRITE_ERR:
+     fprintf(stderr, "TS_WRITE_ERR\n");
      break;
 
-     case INK_TIME_EXPIRE:
-     fprintf(stderr, "INK_TIME_EXPIRE\n");
+     case TS_TIME_EXPIRE:
+     fprintf(stderr, "TS_TIME_EXPIRE\n");
      break;
      } */
 }
 
 
 int
-INKRequestCreate(char *server_host, int max_host_size, char *server_port,
+TSRequestCreate(char *server_host, int max_host_size, char *server_port,
                  int max_port_size, char *request_buf, int max_request_size, void **request_id)
 {
 
@@ -156,7 +156,7 @@ INKRequestCreate(char *server_host, int 
 
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "append-file-path") == 0) {
     if (strlen(value) < MAX_PATH_SIZE) {
@@ -169,7 +169,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   int n;
 
@@ -218,14 +218,14 @@ INKOptionsProcessFinish()
 
 }
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
-INKRequestAction
-INKPartialBodyProcess(void *request_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *request_id, void *partial_content, int partial_length, int accum_length)
 {
   char *src;
   int room;
@@ -237,18 +237,18 @@ INKPartialBodyProcess(void *request_id, 
 
   req_id = (CONN_DATA *) request_id;
   if (req_id == NULL)
-    return INK_STOP_FAIL;
+    return TS_STOP_FAIL;
 
   if (partial_length == 0) {    /* Response is now complete. */
 
     if (memcmp(req_id->tail_of_resp, my_plugin.append_content, my_plugin.append_len) == 0) {
 
-      return INK_STOP_SUCCESS;
+      return TS_STOP_SUCCESS;
     }
 
     fprintf(stderr, "Test Failed: appended content doesn't match\n");
     fprintf(stderr, "append: [%s] tail_of_resp [%s]\n", my_plugin.append_content, req_id->tail_of_resp);
-    return INK_STOP_FAIL;
+    return TS_STOP_FAIL;
   }
 
 /* Response not complete. Copy last _useful_ bytes to tail_of_file buffer */
@@ -273,6 +273,6 @@ INKPartialBodyProcess(void *request_id, 
   req_id->tail_of_resp_index += partial_length;
   req_id->tail_of_resp[req_id->tail_of_resp_index + 1] = '\0';
 
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckReplaceHeader.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckReplaceHeader.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckReplaceHeader.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckReplaceHeader.c Tue Nov 16 20:22:02 2010
@@ -47,15 +47,15 @@
 
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
   fprintf(stderr, "*** CheckReplaceHeader Test for replace-header-plugin ***\n");
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
 }
 
 
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
 
   char *accept_ranges_loc;
@@ -64,7 +64,7 @@ INKHeaderProcess(void *req_id, char *hea
   if (accept_ranges_loc == NULL) {
     fprintf(stderr, "SDKtest: replace-header-Test Failed: Accept-Ranges field error\n");
     fprintf(stderr, "Response header is:\n%s\n", header);
-    return INK_STOP_FAIL;
+    return TS_STOP_FAIL;
   }
 
   while (*accept_ranges_loc != ':')
@@ -78,8 +78,8 @@ INKHeaderProcess(void *req_id, char *hea
   if (strncasecmp(accept_ranges_loc, "Accept-Ranges", 13)) {
     fprintf(stderr, "SDKtest: replace-header-Test Failed: Accept-Ranges field error\n");
     fprintf(stderr, "Response header is:\n%s\n", header);
-    return INK_STOP_FAIL;
+    return TS_STOP_FAIL;
   }
 
-  return INK_STOP_SUCCESS;
+  return TS_STOP_SUCCESS;
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/internal/ClientAPI.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/internal/ClientAPI.h?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/internal/ClientAPI.h (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/internal/ClientAPI.h Tue Nov 16 20:22:02 2010
@@ -30,49 +30,49 @@
 
 typedef enum
 {
-  INK_FID_OPTIONS_PROCESS,
-  INK_FID_OPTIONS_PROCESS_FINISH,
-  INK_FID_CONNECTION_FINISH,
-  INK_FID_PLUGIN_FINISH,
-  INK_FID_REQUEST_CREATE,
-  INK_FID_HEADER_PROCESS,
-  INK_FID_PARTIAL_BODY_PROCESS,
-  INK_FID_REPORT
-} INKPluginFuncId;
+  TS_FID_OPTIONS_PROCESS,
+  TS_FID_OPTIONS_PROCESS_FINISH,
+  TS_FID_CONNECTION_FINISH,
+  TS_FID_PLUGIN_FINISH,
+  TS_FID_REQUEST_CREATE,
+  TS_FID_HEADER_PROCESS,
+  TS_FID_PARTIAL_BODY_PROCESS,
+  TS_FID_REPORT
+} TSPluginFuncId;
 
 typedef enum
 {
-  INK_CONN_COMPLETE,
-  INK_CONN_ERR,
-  INK_READ_ERR,
-  INK_WRITE_ERR,
-  INK_TIME_EXPIRE
-} INKConnectionStatus;
+  TS_CONN_COMPLETE,
+  TS_CONN_ERR,
+  TS_READ_ERR,
+  TS_WRITE_ERR,
+  TS_TIME_EXPIRE
+} TSConnectionStatus;
 
 typedef enum
 {
-  INK_STOP_SUCCESS,
-  INK_STOP_FAIL,
-  INK_KEEP_GOING
-} INKRequestAction;
+  TS_STOP_SUCCESS,
+  TS_STOP_FAIL,
+  TS_KEEP_GOING
+} TSRequestAction;
 
 typedef enum
 {
-  INK_SUM,
-  INK_MAX,
-  INK_MIN,
-  INK_AVE
-} INKReportCombiner;
+  TS_SUM,
+  TS_MAX,
+  TS_MIN,
+  TS_AVE
+} TSReportCombiner;
 
 #ifdef __cplusplus
 extern "C"
 {
 #endif
-  extern void INKPluginInit(int clientID);
+  extern void TSPluginInit(int clientID);
 
-  extern void INKReportSingleData(char *metric, char *unit, INKReportCombiner combiner, double value);
+  extern void TSReportSingleData(char *metric, char *unit, TSReportCombiner combiner, double value);
 
-  extern void INKFuncRegister(INKPluginFuncId fid);
+  extern void TSFuncRegister(TSPluginFuncId fid);
 
 #ifdef __cplusplus
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/internal/TestCacheAPI.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/internal/TestCacheAPI.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/internal/TestCacheAPI.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/internal/TestCacheAPI.c Tue Nov 16 20:22:02 2010
@@ -97,26 +97,26 @@ typedef struct
 SDKtestCachePlugin my_plugin;
 
 void
-INKPluginInit(int client_id)
+TSPluginInit(int client_id)
 {
   my_plugin.requests = 0;
   my_plugin.successful_requests = 0;
 
   /* register the plugin functions that are called back
    * later in the program */
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_CONNECTION_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
-  INKFuncRegister(INK_FID_HEADER_PROCESS);
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
-  INKFuncRegister(INK_FID_REPORT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_CONNECTION_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
+  TSFuncRegister(TS_FID_HEADER_PROCESS);
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 /* process options specified in SDKtest_client.config */
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "target_host") == 0) {
     my_plugin.target_host = strdup(value);
@@ -146,7 +146,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   read_docsize_dist();
   ((strlen(my_plugin.target_host) == 0) || (strlen(my_plugin.target_port) == 0)) ?
@@ -154,15 +154,15 @@ INKOptionsProcessFinish()
 }
 
 void
-INKConnectionFinish(void *req_id, INKConnectionStatus conn_status)
+TSConnectionFinish(void *req_id, TSConnectionStatus conn_status)
 {
-  if (conn_status == INK_TIME_EXPIRE)
+  if (conn_status == TS_TIME_EXPIRE)
     my_plugin.unfinished_requests++;
   free(req_id);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   int i;
   free(my_plugin.target_host);
@@ -181,7 +181,7 @@ INKPluginFinish()
  *     i.e. GET URL HTTP/1.0 ....
  */
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )
@@ -264,18 +264,18 @@ INKRequestCreate(char *origin_server_hos
 /* process response header returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKHeaderProcess(void *req_id, char *header, int length, char *request_str)
+TSRequestAction
+TSHeaderProcess(void *req_id, char *header, int length, char *request_str)
 {
   ((User *) req_id)->header_bytes = length;
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 /* process part of the response returned either from synthetic
  * server or from proxy server
  */
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
   if (partial_length == 0) {
     if (accum_length >= ((User *) req_id)->doc_size_requested) {
@@ -285,18 +285,18 @@ INKPartialBodyProcess(void *req_id, void
       fprintf(stderr, "ERROR: received bytes < requested bytes");
     }
   }
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }
 
 
 /* output report data after the SDKtest report */
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Total Requests", "count", INK_SUM, (double) my_plugin.requests);
-  INKReportSingleData("Successful Documents", "count", INK_SUM, (double) my_plugin.successful_requests);
-  INKReportSingleData("Unfinished Documents", "count", INK_SUM, (double) my_plugin.unfinished_requests);
-  INKReportSingleData("Total Bytes Received", "count", INK_SUM, (double) my_plugin.total_bytes_received);
+  TSReportSingleData("Total Requests", "count", TS_SUM, (double) my_plugin.requests);
+  TSReportSingleData("Successful Documents", "count", TS_SUM, (double) my_plugin.successful_requests);
+  TSReportSingleData("Unfinished Documents", "count", TS_SUM, (double) my_plugin.unfinished_requests);
+  TSReportSingleData("Total Bytes Received", "count", TS_SUM, (double) my_plugin.total_bytes_received);
 }
 
 /******************** ADDED FUNCTIONS ****************************/

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/options_process.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/options_process.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/options_process.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/options_process.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKOptionsProcess Test for Client ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
+  fprintf(stderr, "*** TSOptionsProcess Test for Client ***\n");
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   fprintf(stderr, "%s = %s\n", option, value);
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/options_process_finish.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/options_process_finish.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/options_process_finish.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/options_process_finish.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKOptionsProcessFinish Test for Client ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
+  fprintf(stderr, "*** TSOptionsProcessFinish Test for Client ***\n");
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
-  fprintf(stderr, "\nINKOptionsProcessFinish\n\n");
+  fprintf(stderr, "\nTSOptionsProcessFinish\n\n");
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/partial_body_process.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/partial_body_process.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/partial_body_process.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/partial_body_process.c Tue Nov 16 20:22:02 2010
@@ -29,15 +29,15 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKPartialBodyProcess Test for Client ***\n");
-  INKFuncRegister(INK_FID_PARTIAL_BODY_PROCESS);
+  fprintf(stderr, "*** TSPartialBodyProcess Test for Client ***\n");
+  TSFuncRegister(TS_FID_PARTIAL_BODY_PROCESS);
 }
 
 
-INKRequestAction
-INKPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
+TSRequestAction
+TSPartialBodyProcess(void *req_id, void *partial_content, int partial_length, int accum_length)
 {
-  return INK_KEEP_GOING;
+  return TS_KEEP_GOING;
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/plugin_finish.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/plugin_finish.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/plugin_finish.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/plugin_finish.c Tue Nov 16 20:22:02 2010
@@ -25,13 +25,13 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
-  fprintf(stderr, "INKPluginFinish\n");
+  fprintf(stderr, "TSPluginFinish\n");
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/readme
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/readme?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/readme (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/readme Tue Nov 16 20:22:02 2010
@@ -5,7 +5,7 @@ hello_world.c
 - Example of the most basic routine of writing the SDKtest_client plugin.
 
   This example simply prints a statement to standard error within the 
-  INKPluginInit() to make sure that the plugin is successfully loaded
+  TSPluginInit() to make sure that the plugin is successfully loaded
   when SDKtest_client starts running.
 
 SimSDKtest.c
@@ -13,9 +13,9 @@ SimSDKtest.c
 
   The plugin reads in the origin_servers, hotset, docset, hitrate, and
   docsize_dist_file options specified in the SDKtest_client.config 
-  by registering INKOptionsProcess().  Then it fills in the request
+  by registering TSOptionsProcess().  Then it fills in the request
   headers into the buffer based on the above criteria in
-  INKRequestCreate().  The request headers generated are in the
+  TSRequestCreate().  The request headers generated are in the
   following format:
    
 	GET [www.hostname.com:port]/serial_number/lengthxxx HTTP/1.0
@@ -24,7 +24,7 @@ SimSDKtest.c
 
   Similar to SDKtest, it keeps track of the number of bytes received
   and the number of successful requests and finally report the
-  result through registering INKReport().
+  result through registering TSReport().
 
 SimSDKtestCache.c
 - Simulate the default way of generating requests by the 

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/report.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/report.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/report.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/report.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKPluginFinish Test for Client ***\n");
-  INKFuncRegister(INK_FID_REPORT);
+  fprintf(stderr, "*** TSPluginFinish Test for Client ***\n");
+  TSFuncRegister(TS_FID_REPORT);
 }
 
 void
-INKReport()
+TSReport()
 {
-  INKReportSingleData("Report Test", "count", INK_SUM, 0);
+  TSReportSingleData("Report Test", "count", TS_SUM, 0);
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/request_create.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/request_create.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/client/api/request_create.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/request_create.c Tue Nov 16 20:22:02 2010
@@ -31,14 +31,14 @@
 #define TRUE 1
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
-  fprintf(stderr, "*** INKRequestCreate Test for Client ***\n");
-  INKFuncRegister(INK_FID_REQUEST_CREATE);
+  fprintf(stderr, "*** TSRequestCreate Test for Client ***\n");
+  TSFuncRegister(TS_FID_REQUEST_CREATE);
 }
 
 int
-INKRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
+TSRequestCreate(char *origin_server_host /* return */ , int max_hostname_size,
                  char *origin_server_port /* return */ , int max_portname_size,
                  char *request_buf /* return */ , int max_request_size,
                  void **req_id /* return */ )

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/ServerAPI.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/ServerAPI.h?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/ServerAPI.h (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/ServerAPI.h Tue Nov 16 20:22:02 2010
@@ -30,13 +30,13 @@
 
 typedef enum
 {
-  INK_FID_OPTIONS_PROCESS,
-  INK_FID_OPTIONS_PROCESS_FINISH,
-  INK_FID_PLUGIN_FINISH,
-  INK_FID_RESPONSE_PREPARE,
-  INK_FID_RESPONSE_PUT
-} INKPluginFuncId;
+  TS_FID_OPTIONS_PROCESS,
+  TS_FID_OPTIONS_PROCESS_FINISH,
+  TS_FID_PLUGIN_FINISH,
+  TS_FID_RESPONSE_PREPARE,
+  TS_FID_RESPONSE_PUT
+} TSPluginFuncId;
 
-extern void INKFuncRegister();
+extern void TSFuncRegister();
 
 #endif /* _Api_h_ */

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/CheckContentServer.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/CheckContentServer.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/LogRequest.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/LogRequest.c Tue Nov 16 20:22:02 2010
@@ -56,17 +56,17 @@ typedef struct
 LogRequestPlugin my_plugin;
 
 void
-INKPluginInit()
+TSPluginInit()
 {
   fprintf(stderr, "*** LogRequest Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
-  INKFuncRegister(INK_FID_RESPONSE_PREPARE);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
+  TSFuncRegister(TS_FID_RESPONSE_PREPARE);
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   if (strcmp(option, "log_path") == 0) {
     if (strlen(value) < MAX_PATH_SIZE) {
@@ -79,7 +79,7 @@ INKOptionsProcess(char *option, char *va
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
   if (!(my_plugin.request_log = fopen(my_plugin.log_path, "a"))) {
     fprintf(stderr, "Error: Unable to open %s\n", my_plugin.log_path);
@@ -88,14 +88,14 @@ INKOptionsProcessFinish()
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
   fclose(my_plugin.request_log);
 }
 
 
 int
-INKResponsePrepare(char *req_hdr, int req_len, void **response_id)
+TSResponsePrepare(char *req_hdr, int req_len, void **response_id)
 {
   char log_string[MAX_LOG_STR_SIZE + 1];
   char *time_string;

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/ServerAPI.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/ServerAPI.h?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/ServerAPI.h (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/ServerAPI.h Tue Nov 16 20:22:02 2010
@@ -30,14 +30,14 @@
 
 typedef enum
 {
-  INK_FID_OPTIONS_PROCESS,
-  INK_FID_OPTIONS_PROCESS_FINISH,
-  INK_FID_PLUGIN_FINISH,
-  INK_FID_RESPONSE_PREPARE,
-  INK_FID_RESPONSE_PUT
-} INKPluginFuncId;
+  TS_FID_OPTIONS_PROCESS,
+  TS_FID_OPTIONS_PROCESS_FINISH,
+  TS_FID_PLUGIN_FINISH,
+  TS_FID_RESPONSE_PREPARE,
+  TS_FID_RESPONSE_PUT
+} TSPluginFuncId;
 
-extern void INKPluginInit();
-extern void INKFuncRegister(INKPluginFuncId);
+extern void TSPluginInit();
+extern void TSFuncRegister(TSPluginFuncId);
 
 #endif /* _Api_h_ */

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServer.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServer.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServerCache.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServerCache.c Tue Nov 16 20:22:02 2010
@@ -73,7 +73,7 @@ generate_cachability()
 
 
 void
-INKOptionProcess(char *option, char *value)
+TSOptionProcess(char *option, char *value)
 {
   if (strcmp(option, "cachability") == 0) {
     my_plugin.cachability_ratio = (double) (atoi(value)) / 100.0;
@@ -82,17 +82,17 @@ INKOptionProcess(char *option, char *val
 
 
 void
-INKPluginInit()
+TSPluginInit()
 {
   fprintf(stderr, "*** SimSynthServerCache for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
-  INKFuncRegister(INK_FID_RESPONSE_PREPARE);
-  INKFuncRegister(INK_FID_RESPONSE_PUT);
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
+  TSFuncRegister(TS_FID_RESPONSE_PREPARE);
+  TSFuncRegister(TS_FID_RESPONSE_PUT);
 }
 
 /* prepare response header for a request */
 int
-INKResponsePrepare(char *req_hdr, int req_len, void **response_id)
+TSResponsePrepare(char *req_hdr, int req_len, void **response_id)
 {
   char *len_string;
   RequestInfo *resp_id = (RequestInfo *) malloc(sizeof(RequestInfo));
@@ -125,7 +125,7 @@ INKResponsePrepare(char *req_hdr, int re
 
 /* put response (response header + response document) into buffer */
 void
-INKResponsePut(void **resp_id /* return */ ,
+TSResponsePut(void **resp_id /* return */ ,
                void *resp_buffer /* return */ ,
                int *resp_bytes /* return */ ,
                int resp_buffer_size, int bytes_last_response)
@@ -156,7 +156,7 @@ INKResponsePut(void **resp_id /* return 
     }
   }
   /* return NULL as the resp_id to indicate
-   * if it is the last INKResponsePut call */
+   * if it is the last TSResponsePut call */
   if (rid->bytes_not_sent <= 0 || rid->status_code != 200) {
     free(rid);
     *((RequestInfo **) resp_id) = NULL;

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/hello_world.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/hello_world.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit()
+TSPluginInit()
 {
-  fprintf(stderr, "*** INKOptionsProcess Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS);
+  fprintf(stderr, "*** TSOptionsProcess Test for Synthetic Server ***\n");
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS);
 }
 
 void
-INKOptionsProcess(char *option, char *value)
+TSOptionsProcess(char *option, char *value)
 {
   fprintf(stderr, "%s = %s\n", option, value);
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process_finish.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process_finish.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process_finish.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process_finish.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit()
+TSPluginInit()
 {
-  fprintf(stderr, "*** INKOptionsProcessFinish Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_OPTIONS_PROCESS_FINISH);
+  fprintf(stderr, "*** TSOptionsProcessFinish Test for Synthetic Server ***\n");
+  TSFuncRegister(TS_FID_OPTIONS_PROCESS_FINISH);
 }
 
 void
-INKOptionsProcessFinish()
+TSOptionsProcessFinish()
 {
-  fprintf(stderr, "\nINKOptionsProcessFinish\n\n");
+  fprintf(stderr, "\nTSOptionsProcessFinish\n\n");
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/plugin_finish.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/plugin_finish.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/plugin_finish.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/plugin_finish.c Tue Nov 16 20:22:02 2010
@@ -29,14 +29,14 @@
 #include <stdio.h>
 
 void
-INKPluginInit()
+TSPluginInit()
 {
-  fprintf(stderr, "*** INKPluginFinish Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_PLUGIN_FINISH);
+  fprintf(stderr, "*** TSPluginFinish Test for Synthetic Server ***\n");
+  TSFuncRegister(TS_FID_PLUGIN_FINISH);
 }
 
 void
-INKPluginFinish()
+TSPluginFinish()
 {
-  fprintf(stderr, "\nINKPluginFinish\n\n");
+  fprintf(stderr, "\nTSPluginFinish\n\n");
 }

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/readme
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/readme?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/readme (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/readme Tue Nov 16 20:22:02 2010
@@ -5,7 +5,7 @@ hello_world.c
 - Demonstrate the most basic routine of writing the SDKtest_server plugin
 
   This example simply prints a statement to standard error within the 
-  INKPluginInit() to make sure that the plugin is successfully loaded
+  TSPluginInit() to make sure that the plugin is successfully loaded
   when SDKtest_server starts running.
 
 SimSynthServer.c

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/response_prepare.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/response_prepare.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/response_prepare.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/response_prepare.c Tue Nov 16 20:22:02 2010
@@ -31,14 +31,14 @@
 #define FALSE 0
 
 void
-INKPluginInit()
+TSPluginInit()
 {
-  fprintf(stderr, "*** INKResponsePrepare Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_RESPONSE_PREPARE);
+  fprintf(stderr, "*** TSResponsePrepare Test for Synthetic Server ***\n");
+  TSFuncRegister(TS_FID_RESPONSE_PREPARE);
 }
 
 int
-INKResponsePrepare(char *request_header, int request_len, void **response_id)
+TSResponsePrepare(char *request_header, int request_len, void **response_id)
 {
 
   /* return FALSE implies that no response will be given from the plugin

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/synth_server.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/synth_server.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/synth_server.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/synth_server.c Tue Nov 16 20:22:02 2010
@@ -217,9 +217,9 @@ typedef struct
   PluginFinish plugin_finish_fcn;
   ResponsePrepare response_prepare_fcn;
   ResponsePut response_put_fcn;
-} INKPlugin;
+} TSPlugin;
 
-INKPlugin plug_in;
+TSPlugin plug_in;
 
 void
 plugin_initialize(char *api)
@@ -243,10 +243,10 @@ plugin_initialize(char *api)
       perror("server plugin");
       exit(1);
     }
-    plug_in.plugin_init_fcn = (PluginInit) dlsym(plug_in.handle, "INKPluginInit");
+    plug_in.plugin_init_fcn = (PluginInit) dlsym(plug_in.handle, "TSPluginInit");
 
     if (!plug_in.plugin_init_fcn) {
-      fprintf(stderr, "unable to find INKPluginInit function: %s", dlerror());
+      fprintf(stderr, "unable to find TSPluginInit function: %s", dlerror());
       dlclose(plug_in.handle);
       exit(1);
     }
@@ -254,26 +254,26 @@ plugin_initialize(char *api)
 }
 
 void
-INKFuncRegister(INKPluginFuncId fid)
+TSFuncRegister(TSPluginFuncId fid)
 {
   switch (fid) {
-  case INK_FID_OPTIONS_PROCESS:
-    plug_in.options_process_fcn = (OptionsProcess) dlsym(plug_in.handle, "INKOptionsProcess");
+  case TS_FID_OPTIONS_PROCESS:
+    plug_in.options_process_fcn = (OptionsProcess) dlsym(plug_in.handle, "TSOptionsProcess");
     break;
-  case INK_FID_OPTIONS_PROCESS_FINISH:
-    plug_in.options_process_finish_fcn = (OptionsProcessFinish) dlsym(plug_in.handle, "INKOptionsProcessFinish");
+  case TS_FID_OPTIONS_PROCESS_FINISH:
+    plug_in.options_process_finish_fcn = (OptionsProcessFinish) dlsym(plug_in.handle, "TSOptionsProcessFinish");
     break;
-  case INK_FID_PLUGIN_FINISH:
-    plug_in.plugin_finish_fcn = (PluginFinish) dlsym(plug_in.handle, "INKPluginFinish");
+  case TS_FID_PLUGIN_FINISH:
+    plug_in.plugin_finish_fcn = (PluginFinish) dlsym(plug_in.handle, "TSPluginFinish");
     break;
-  case INK_FID_RESPONSE_PREPARE:
-    plug_in.response_prepare_fcn = (ResponsePrepare) dlsym(plug_in.handle, "INKResponsePrepare");
+  case TS_FID_RESPONSE_PREPARE:
+    plug_in.response_prepare_fcn = (ResponsePrepare) dlsym(plug_in.handle, "TSResponsePrepare");
     break;
-  case INK_FID_RESPONSE_PUT:
-    plug_in.response_put_fcn = (ResponsePut) dlsym(plug_in.handle, "INKResponsePut");
+  case TS_FID_RESPONSE_PUT:
+    plug_in.response_put_fcn = (ResponsePut) dlsym(plug_in.handle, "TSResponsePut");
     break;
   default:
-    fprintf(stderr, "Can't register function: unknown type of INKPluginFuncId");
+    fprintf(stderr, "Can't register function: unknown type of TSPluginFuncId");
     break;
   }
 }

Modified: trafficserver/traffic/trunk/test/deft/proc_manager.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/deft/proc_manager.cc?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/deft/proc_manager.cc (original)
+++ trafficserver/traffic/trunk/test/deft/proc_manager.cc Tue Nov 16 20:22:02 2010
@@ -51,9 +51,9 @@
 #include "ParseRules.h"
 #include "Ptr.h"
 #include "Tokenizer.h"
-#define INK_LOCKFILE_INCLUDE_REDUCED
+#define TS_LOCKFILE_INCLUDE_REDUCED
 #include "ink_lockfile.h"
-#undef INK_LOCKFILE_INCLUDE_REDUCED
+#undef TS_LOCKFILE_INCLUDE_REDUCED
 
 /* Globals */
 int num_active_process = 0;
--- trafficserver/traffic/trunk/test/SDKtest/client/api/hello_world.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/client/api/hello_world.c Tue Nov 16 20:22:02 2010
@@ -32,10 +32,10 @@
 #include "ClientAPI.h"
 #include <stdio.h>
 
 /* INKPluginInit() must be provided */
 
 void
-INKPluginInit(int clientid)
+TSPluginInit(int clientid)
 {
   fprintf(stderr, "hello world!!!\n");
 }
@@ -32,10 +32,10 @@
 #include <stdio.h>
 
-/* INKPluginInit() must be provided */
+/* TSPluginInit() must be provided */
 
 void

Modified: trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckAppend.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/client/api/internal/CheckAppend.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/CheckContentServer.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/CheckContentServer.c Tue Nov 16 20:22:02 2010
@@ -61,7 +61,7 @@ CheckContentPlugin my_plugin;
 
 
 void
-INKPluginInit()
+TSPluginInit()
 {
   int i = 0;
 
@@ -75,14 +75,14 @@ INKPluginInit()
   my_plugin.content[i] = '\0';
 
   /* register functions to be callbacked */
-  INKFuncRegister(INK_FID_RESPONSE_PREPARE);
-  INKFuncRegister(INK_FID_RESPONSE_PUT);
+  TSFuncRegister(TS_FID_RESPONSE_PREPARE);
+  TSFuncRegister(TS_FID_RESPONSE_PUT);
 }
 
 
 
 int
-INKResponsePrepare(char *req_hdr, int req_len, void **response_id)
+TSResponsePrepare(char *req_hdr, int req_len, void **response_id)
 {
   char *len_string;
   RequestInfo *resp_id = (RequestInfo *) malloc(sizeof(RequestInfo));
@@ -108,7 +108,7 @@ INKResponsePrepare(char *req_hdr, int re
 
 
 void
-INKResponsePut(void **resp_id /* return */ ,
+TSResponsePut(void **resp_id /* return */ ,
                void *resp_buffer /* return */ ,
                int *resp_bytes /* return */ ,
                int resp_buffer_size, int bytes_last_response)
@@ -140,7 +140,7 @@ INKResponsePut(void **resp_id /* return 
     }
   }
   /* return NULL as the resp_id to indicate
    * that it is the last INKResponsePut call */
   if (rid->bytes_not_sent <= 0 || rid->status_code != 200) {
     free(rid);
     *((RequestInfo **) resp_id) = NULL;
@@ -140,7 +140,7 @@ INKResponsePut(void **resp_id /* return 
   }
   /* return NULL as the resp_id to indicate
-   * that it is the last INKResponsePut call */
+   * that it is the last TSResponsePut call */
   if (rid->bytes_not_sent <= 0 || rid->status_code != 200) {
     free(rid);

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/LogRequest.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/LogRequest.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServer.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServer.c Tue Nov 16 20:22:02 2010
@@ -48,16 +48,16 @@ typedef struct
 } RequestInfo;
 
 void
-INKPluginInit()
+TSPluginInit()
 {
   fprintf(stderr, "*** SimSynthServer Test for Synthetic Server ***\n");
-  INKFuncRegister(INK_FID_RESPONSE_PREPARE);
-  INKFuncRegister(INK_FID_RESPONSE_PUT);
+  TSFuncRegister(TS_FID_RESPONSE_PREPARE);
+  TSFuncRegister(TS_FID_RESPONSE_PUT);
 }
 
 /* prepare response header for a request */
 int
-INKResponsePrepare(char *req_hdr, int req_len, void **response_id)
+TSResponsePrepare(char *req_hdr, int req_len, void **response_id)
 {
   char *len_string;
   RequestInfo *resp_id = (RequestInfo *) malloc(sizeof(RequestInfo));
@@ -82,7 +82,7 @@ INKResponsePrepare(char *req_hdr, int re
 
 /* put response (response header + response document) into buffer */
 void
-INKResponsePut(void **resp_id /* return */ ,
+TSResponsePut(void **resp_id /* return */ ,
                void *resp_buffer /* return */ ,
                int *resp_bytes /* return */ ,
                int resp_buffer_size, int bytes_last_response)
@@ -113,7 +113,7 @@ INKResponsePut(void **resp_id /* return 
     }
   }
   /* return NULL as the resp_id to indicate
    * that it is the last INKResponsePut call */
   if (rid->bytes_not_sent <= 0 || rid->status_code != 200) {
     free(rid);
     *((RequestInfo **) resp_id) = NULL;
@@ -113,7 +113,7 @@ INKResponsePut(void **resp_id /* return 
   }
   /* return NULL as the resp_id to indicate
-   * that it is the last INKResponsePut call */
+   * that it is the last TSResponsePut call */
   if (rid->bytes_not_sent <= 0 || rid->status_code != 200) {
     free(rid);

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServerCache.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/SimSynthServerCache.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================
--- trafficserver/traffic/trunk/test/SDKtest/synth_server/api/hello_world.c (original)
+++ trafficserver/traffic/trunk/test/SDKtest/synth_server/api/hello_world.c Tue Nov 16 20:22:02 2010
@@ -32,10 +32,10 @@
 #include "ServerAPI.h"
 #include <stdio.h>
 
 /* INKPluginInit() must be provided */
 
 void
-INKPluginInit()
+TSPluginInit()
 {
   fprintf(stderr, "hello world???\n");
 }
@@ -32,10 +32,10 @@
 #include <stdio.h>
 
-/* INKPluginInit() must be provided */
+/* TSPluginInit() must be provided */
 
 void

Modified: trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process.c
URL: http://svn.apache.org/viewvc/trafficserver/traffic/trunk/test/SDKtest/synth_server/api/options_process.c?rev=1035782&r1=1035781&r2=1035782&view=diff
==============================================================================